@@ -1,6 +1,9 @@
-/* $Id: isdnl3.c,v 1.5 1996/05/18 01:37:16 fritz Exp $
+/* $Id: isdnl3.c,v 1.6 1996/05/21 11:33:50 keil Exp $
  *
  * $Log: isdnl3.c,v $
+ * Revision 1.6  1996/05/21 11:33:50  keil
+ * Adding SETUP_ACKNOWLEGDE as answer of a SETUP message.
+ *
  * Revision 1.5  1996/05/18 01:37:16  fritz
  * Added spelling corrections and some minor changes
  * to stay in sync with kernel.
@@ -421,6 +424,7 @@ static struct stateentry datastatelist[] =
 {
         {0,MT_SETUP,l3s12},
         {1,MT_CALL_PROCEEDING,l3s6},
+        {1,MT_SETUP_ACKNOWLEDGE,l3s6},
         {1,MT_RELEASE_COMPLETE,l3s4},
         {1,MT_RELEASE,l3s19},
         {1,MT_DISCONNECT,l3s7},
